@@ -88,16 +88,16 @@ def saveData(obj, fullpath):
 
 
 def loadData(fullpath):
-    if not filepath:
+    if not fullpath:
         return None
-    if not os.path.exists(filepath):
+    if not os.path.exists(fullpath):
         return None
     with open(fullpath, 'r') as file:
         content = file.read()
     try:
         return json.loads(content)
     except Exception as e:
-        return []
+        return None
 
 
 def requestJson(url):
@@ -106,7 +106,7 @@ def requestJson(url):
 
 
 def dumps(data):
-    return json.dumps(data, ensure_ascii=0, indent=2)
+    return json.dumps(data, ensure_ascii=False, indent=2)
 
 
 def getFiles(file_path='.'):
@@ -144,11 +144,8 @@ def makeFilePath(path):
     arr = path.split('/')
     if len(arr) == 1:
         return
-    p = ''
-    for i in range(len(arr) - 1):
-        p = os.path.join(p, arr[i])
-        if not os.path.exists(p):
-            os.mkdir(p)
+    filepath = os.path.join(*arr[:-1])
+    makeDir(filepath)
 
 
 def copyfile(src, dest):
